@@ -12,7 +12,7 @@ class CacheMiss(Exception):
 
 class Config(object):
     def __init__(self, **kwargs):
-        self.resource_exemptions = kwargs.pop('resource_exemptions', ())
+        self.resource_exemptions = set(kwargs.pop('resource_exemptions', ()))
         self.master_salt = kwargs.pop('master_salt', '')
         if kwargs:
             raise TypeError("%s got an unexpected keyword argument %r"
